==> atmosphere-di-guice-sample-0.7.2-sources.jar: org/atmosphere/samples/di/guice/GuiceContextListener.java <==
/*
 * Copyright 2011 Jeanfrancois Arcand
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.atmosphere.samples.di.guice;

import com.google.inject.Guice;
import com.google.inject.Injector;
import com.google.inject.servlet.GuiceServletContextListener;
import com.google.inject.servlet.ServletModule;
import com.sun.jersey.guice.spi.container.servlet.GuiceContainer;
import org.atmosphere.guice.GuiceManagedAtmosphereServlet;

import java.util.HashMap;

/**
 * @author Mathieu Carbou
 * @since 0.7
 */
public final class GuiceContextListener extends GuiceServletContextListener {
    @Override
    protected Injector getInjector() {
        return Guice.createInjector(new ServletModule() {
            @Override
            protected void configureServlets() {
                bind(MessageResource.class);
                serve("/async/*").with(GuiceManagedAtmosphereServlet.class, new HashMap<String, String>() {
                    {
                        put("org.atmosphere.useWebSocket", "true");
                        put("org.atmosphere.useNative", "true");
                    }
                });
                serve("/rest/*").with(GuiceContainer.class);
            }
        });
    }
}

==> atmosphere-di-guice-sample-0.8.7-sources.jar: org/atmosphere/samples/di/guice/GuiceContextListener.java <==
/*
 * Copyright 2011 Jeanfrancois Arcand
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.atmosphere.samples.di.guice;

import com.google.inject.Guice;
import com.google.inject.Injector;
import com.google.inject.servlet.GuiceServletContextListener;
import com.google.inject.servlet.ServletModule;
import org.atmosphere.guice.GuiceContainer;
import org.atmosphere.guice.GuiceManagedAtmosphereServlet;

import java.util.HashMap;

/**
 * @author Mathieu Carbou
 * @since 0.7
 */
public final class GuiceContextListener extends GuiceServletContextListener {
    @Override
    protected Injector getInjector() {
        return Guice.createInjector(new ServletModule() {
            @Override
            protected void configureServlets() {
                bind(MessageResource.class);
                serve("/async/*").with(GuiceManagedAtmosphereServlet.class, new HashMap<String, String>() {
                    {
                        put("org.atmosphere.useWebSocket", "true");
                        put("org.atmosphere.useNative", "true");
                    }
                });
                serve("/rest/*").with(GuiceContainer.class);
            }
        });
    }
}
